@@ -1,5 +1,3 @@
-/* $Id: close.c,v 1.14 2003/10/19 16:10:21 carlos Exp $ */
-
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
 
@@ -21,8 +19,10 @@
    Boston, MA 02111-1307, USA.
 */
 
+#include <config.h>
 #include <glibtop.h>
 #include <glibtop/open.h>
+#include <glibtop/error.h>
 #include <glibtop/close.h>
 #include <glibtop/command.h>
 
