@@ -1,5 +1,3 @@
-/* $Id: procmem.c,v 1.6 1999/02/23 11:46:28 martin Exp $ */
-
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
 
@@ -21,6 +19,7 @@
    Boston, MA 02111-1307, USA.
 */
 
+#include <config.h>
 #include <glibtop.h>
 #include <glibtop/procmem.h>
 
@@ -29,7 +28,7 @@ static const unsigned long _glibtop_sysdeps_proc_mem = 0;
 /* Init function. */
 
 void
-glibtop_init_proc_mem_s (glibtop *server)
+_glibtop_init_proc_mem_s (glibtop *server)
 {
 	server->sysdeps.proc_mem = _glibtop_sysdeps_proc_mem;
 }
